@@ -2,7 +2,7 @@
 #
 # Released under the GPL
 
-INTERFACE="`hciconfig | grep "^hci" | cut -d ':' -f 1`"
+INTERFACE="`/usr/sbin/hciconfig | grep "^hci" | cut -d ':' -f 1`"
 LOCK=".op_btenabled"
 cd "$HOME"
 
@@ -12,7 +12,7 @@ if [ "$1" = "startup" ]; then
 else	
 	# Figure out if Bluetooth is running or not
 	
-	if hciconfig "$INTERFACE" | grep UP &>/dev/null
+	if /usr/sbin/hciconfig "$INTERFACE" | grep UP &>/dev/null
 	then
 		notify-send -u normal "Bluetooth" "Bluetooth is being disabled..." -i blueman -t 5000
 		sudo /usr/sbin/hciconfig ${INTERFACE} down 1>/dev/null
