@@ -13,8 +13,8 @@ if [ "$1" = "1" ]; then
 		echo out > /sys/class/gpio/gpio15/direction
 	fi
 	echo 1 > /sys/class/gpio/gpio15/value
-	hciattach /dev/ttyO0 texasalt 3000000
-	INTERFACE="`hciconfig | grep "^hci" | cut -d ':' -f 1`"
+	/usr/sbin/hciattach /dev/ttyO0 texasalt 3000000
+	INTERFACE="`/usr/sbin/hciconfig | grep "^hci" | cut -d ':' -f 1`"
 	if [ -z "$INTERFACE" ]; then
 		killall hciattach
 		echo 0 > /sys/class/gpio/gpio15/value
